==> maDB_1.4.0.tar.gz: maDB/man/getExperimentDBInfo.Rd <==
\name{dbGetExperimentInfo}
\alias{dbGetExperimentInfo}
\title{List information about an experiment from a database.}
\description{
  \code{dbGetExperimentInfo} This function lists all experiments that are stored into a database with the \code{publishToDB} function, or lists all properties from a particular experiment.
}
\usage{
dbGetExperimentInfo(Con,exp.title)
}
\arguments{
  \item{Con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{exp.title}{The experiment title (name) from the experiment which properties should be listet. If nothing is submitted a list with all experiments that are stored in the database is displayed.}
}
\details{
This function collects information about the specified experiment over all tables and lists this information. A table is returned, that contains all primary keys or foreign keys with wich all data can be retrieved for the particular experiment from the various tables. This tables are:
\item{experiments}{Primary information about the experiment}
\item{arrays}{the arrays od GeneChips which where used in the experiment}
\item{signal\_channels}{in two color micro arrays two signal channels exist and therefore two entries in the signal\_channels table reference to one entry in the arrays table. For Affymetrix GeneChips the reference is one to one.}
\item{exp\_values}{this table contains all the expression values from the corresponding signal channels of the experiment. The reference to the signal\_channels table is established by the signal\_channels\_fk column in the exp\_values table.}
\item{samples}{Each entry in this table references to one or more entries in the signal\_channels table. This table contains information about the samples that were hybridized onto the arrays.}
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{dbGetAnnotation}}
    \code{\link{publishToDB}}
    \code{\link{dbConnect}}
    \code{\link{EexprSet-class}}
}

\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/getExperimentDBInfo.Rd <==
\name{dbGetExperimentInfo}
\alias{dbGetExperimentInfo}
\title{List information about an experiment from a database.}
\description{
  \code{dbGetExperimentInfo} This function lists all experiments that are stored into a database with the \code{publishToDB} function, or lists all properties from a particular experiment.
}
\usage{
dbGetExperimentInfo(Con,exp.title)
}
\arguments{
  \item{Con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{exp.title}{The experiment title (name) from the experiment which properties should be listet. If nothing is submitted a list with all experiments that are stored in the database is displayed.}
}
\details{
This function collects information about the specified experiment over all tables and lists this information. A table is returned, that contains all primary keys or foreign keys with wich all data can be retrieved for the particular experiment from the various tables. This tables are:
\item{experiments}{Primary information about the experiment}
\item{arrays}{the arrays od GeneChips which where used in the experiment}
\item{signal\_channels}{in two color micro arrays two signal channels exist and therefore two entries in the signal\_channels table reference to one entry in the arrays table. For Affymetrix GeneChips the reference is one to one.}
\item{exp\_values}{this table contains all the expression values from the corresponding signal channels of the experiment. The reference to the signal\_channels table is established by the signal\_channels\_fk column in the exp\_values table.}
\item{samples}{Each entry in this table references to one or more entries in the signal\_channels table. This table contains information about the samples that were hybridized onto the arrays.}
}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{dbGetAnnotation}}
    \code{\link{publishToDB}}
%    \code{\link{dbConnect}}
    \code{\link{EexprSet-class}}
}

\keyword{data}
